# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkHistogramToEntropyImageFilterPython
else:
    import _itkHistogramToEntropyImageFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkHistogramPython
import itk.itkArrayPython
import itk.vnl_vectorPython
import itk.stdcomplexPython
import itk.pyBasePython
import itk.vnl_matrixPython
import itk.itkSamplePython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.itkFixedArrayPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageSourcePython
import itk.itkImageSourceCommonPython
import itk.itkImagePython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.itkIndexPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkImageRegionPython
import itk.itkVectorImagePython
import itk.itkVariableLengthVectorPython
import itk.itkPhasedArray3DSpecialCoordinatesImagePython

def itkHistogramToEntropyImageFilterHDIF2_Superclass_New():
    return itkHistogramToEntropyImageFilterHDIF2_Superclass.New()

class itkHistogramToEntropyImageFilterHDIF2_Superclass(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHDIF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHDIF2_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHDIF2_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramD const *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramD"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramEntropyFunction< unsigned long,float > const &

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float > const &
        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHDIF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHDIF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHDIF2_Superclass

        Create a new object of the class itkHistogramToEntropyImageFilterHDIF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHDIF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHDIF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHDIF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHDIF2_Superclass in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Superclass_swigregister(itkHistogramToEntropyImageFilterHDIF2_Superclass)

def itkHistogramToEntropyImageFilterHDIF3_Superclass_New():
    return itkHistogramToEntropyImageFilterHDIF3_Superclass.New()

class itkHistogramToEntropyImageFilterHDIF3_Superclass(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHDIF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHDIF3_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHDIF3_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramD const *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramD"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramEntropyFunction< unsigned long,float > const &

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float > const &
        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHDIF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHDIF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHDIF3_Superclass

        Create a new object of the class itkHistogramToEntropyImageFilterHDIF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHDIF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHDIF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHDIF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHDIF3_Superclass in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Superclass_swigregister(itkHistogramToEntropyImageFilterHDIF3_Superclass)

def itkHistogramToEntropyImageFilterHFIF2_Superclass_New():
    return itkHistogramToEntropyImageFilterHFIF2_Superclass.New()

class itkHistogramToEntropyImageFilterHFIF2_Superclass(itk.itkImageSourcePython.itkImageSourceIF2):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHFIF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHFIF2_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHFIF2_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramF const *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramF"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramEntropyFunction< unsigned long,float > const &

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float > const &
        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHFIF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHFIF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHFIF2_Superclass

        Create a new object of the class itkHistogramToEntropyImageFilterHFIF2_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHFIF2_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHFIF2_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHFIF2_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHFIF2_Superclass in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Superclass_swigregister(itkHistogramToEntropyImageFilterHFIF2_Superclass)

def itkHistogramToEntropyImageFilterHFIF3_Superclass_New():
    return itkHistogramToEntropyImageFilterHFIF3_Superclass.New()

class itkHistogramToEntropyImageFilterHFIF3_Superclass(itk.itkImageSourcePython.itkImageSourceIF3):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHFIF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHFIF3_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHFIF3_Superclass_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_Clone(self)

    def SetInput(self, input):
        r"""
        SetInput(self, input)

        Parameters
        ----------
        input: itkHistogramF const *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_SetInput(self, input)

    def GetInput(self):
        r"""GetInput(self) -> itkHistogramF"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_GetInput(self)

    def SetFunctor(self, functor):
        r"""
        SetFunctor(self, functor)

        Parameters
        ----------
        functor: itk::Function::HistogramEntropyFunction< unsigned long,float > const &

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_SetFunctor(self, functor)

    def GetFunctor(self, *args):
        r"""
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float >
        GetFunctor(self) -> itk::Function::HistogramEntropyFunction< unsigned long,float > const &
        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_GetFunctor(self, *args)

    def SetTotalFrequency(self, n):
        r"""
        SetTotalFrequency(self, n)

        Parameters
        ----------
        n: unsigned long

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_SetTotalFrequency(self, n)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHFIF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHFIF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHFIF3_Superclass

        Create a new object of the class itkHistogramToEntropyImageFilterHFIF3_Superclass and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHFIF3_Superclass.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHFIF3_Superclass.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHFIF3_Superclass.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHFIF3_Superclass in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Superclass_swigregister(itkHistogramToEntropyImageFilterHFIF3_Superclass)

def itkHistogramToEntropyImageFilterHDIF2_New():
    return itkHistogramToEntropyImageFilterHDIF2.New()

class itkHistogramToEntropyImageFilterHDIF2(itkHistogramToEntropyImageFilterHDIF2_Superclass):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHDIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHDIF2_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHDIF2_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_Clone(self)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHDIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHDIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHDIF2

        Create a new object of the class itkHistogramToEntropyImageFilterHDIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHDIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHDIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHDIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHDIF2 in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF2_swigregister(itkHistogramToEntropyImageFilterHDIF2)

def itkHistogramToEntropyImageFilterHDIF3_New():
    return itkHistogramToEntropyImageFilterHDIF3.New()

class itkHistogramToEntropyImageFilterHDIF3(itkHistogramToEntropyImageFilterHDIF3_Superclass):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHDIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHDIF3_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHDIF3_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_Clone(self)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHDIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHDIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHDIF3

        Create a new object of the class itkHistogramToEntropyImageFilterHDIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHDIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHDIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHDIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHDIF3 in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHDIF3_swigregister(itkHistogramToEntropyImageFilterHDIF3)

def itkHistogramToEntropyImageFilterHFIF2_New():
    return itkHistogramToEntropyImageFilterHFIF2.New()

class itkHistogramToEntropyImageFilterHFIF2(itkHistogramToEntropyImageFilterHFIF2_Superclass):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHFIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHFIF2_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHFIF2_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_Clone(self)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHFIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHFIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHFIF2

        Create a new object of the class itkHistogramToEntropyImageFilterHFIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHFIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHFIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHFIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHFIF2 in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF2_swigregister(itkHistogramToEntropyImageFilterHFIF2)

def itkHistogramToEntropyImageFilterHFIF3_New():
    return itkHistogramToEntropyImageFilterHFIF3.New()

class itkHistogramToEntropyImageFilterHFIF3(itkHistogramToEntropyImageFilterHFIF3_Superclass):
    r"""Proxy of C++ itkHistogramToEntropyImageFilterHFIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkHistogramToEntropyImageFilterHFIF3_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkHistogramToEntropyImageFilterHFIF3_Pointer"""
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_Clone(self)
    __swig_destroy__ = _itkHistogramToEntropyImageFilterPython.delete_itkHistogramToEntropyImageFilterHFIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkHistogramToEntropyImageFilterHFIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkHistogramToEntropyImageFilterHFIF3

        Create a new object of the class itkHistogramToEntropyImageFilterHFIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkHistogramToEntropyImageFilterHFIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkHistogramToEntropyImageFilterHFIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkHistogramToEntropyImageFilterHFIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkHistogramToEntropyImageFilterHFIF3 in _itkHistogramToEntropyImageFilterPython:
_itkHistogramToEntropyImageFilterPython.itkHistogramToEntropyImageFilterHFIF3_swigregister(itkHistogramToEntropyImageFilterHFIF3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_to_image_filter(*args,  functor=..., total_frequency: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramToImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'total_frequency':total_frequency }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramToImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_to_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.HistogramToImageFilter
    histogram_to_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_to_image_filter.__doc__ = filter_object.__doc__

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def histogram_to_entropy_image_filter(*args,  functor=..., total_frequency: int=...,**kwargs)-> itkt.ImageSourceReturn:
    """Functional interface for HistogramToEntropyImageFilter"""
    import itk

    kwarg_typehints = { 'functor':functor,'total_frequency':total_frequency }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.HistogramToEntropyImageFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def histogram_to_entropy_image_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.HistogramToEntropyImageFilter
    histogram_to_entropy_image_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    histogram_to_entropy_image_filter.__doc__ = filter_object.__doc__



